    Pipeline(steps=[('column_selector',
                     ColumnSelector(cols=['alcohol', 'density', 'fixed acidity',
                                          'residual sugar', 'sulphates',
                                          'volatile acidity', 'citric acid',
                                          'free sulfur dioxide', 'pH', 'chlorides',
                                          'total sulfur dioxide'])),
                    ('preprocessor',
                     ColumnTransformer(remainder='passthrough', sparse_threshold=0,
                                       transformers=[('numerical',
                                                      Pipeline(steps=[('converter',
                                                                       Functi...
                                                       'citric acid',
                                                       'free sulfur dioxide', 'pH',
                                                       'chlorides',
                                                       'total sulfur dioxide'])])),
                    ('regressor',
                     LGBMRegressor(colsample_bytree=0.6505873538375593,
                                   lambda_l1=497.23364507194253,
                                   lambda_l2=10.247278083927856,
                                   learning_rate=0.010591811060159174, max_bin=496,
                                   max_depth=5, min_child_samples=41,
                                   n_estimators=162, num_leaves=9,
                                   random_state=668290694,
                                   subsample=0.6795749046696467))])

In a Jupyter environment, please rerun this cell to show the HTML representation or trust the notebook.
On GitHub, the HTML representation is unable to render, please try loading this page with nbviewer.org.
Pipeline

    Pipeline(steps=[('column_selector',
                     ColumnSelector(cols=['alcohol', 'density', 'fixed acidity',
                                          'residual sugar', 'sulphates',
                                          'volatile acidity', 'citric acid',
                                          'free sulfur dioxide', 'pH', 'chlorides',
                                          'total sulfur dioxide'])),
                    ('preprocessor',
                     ColumnTransformer(remainder='passthrough', sparse_threshold=0,
                                       transformers=[('numerical',
                                                      Pipeline(steps=[('converter',
                                                                       Functi...
                                                       'citric acid',
                                                       'free sulfur dioxide', 'pH',
                                                       'chlorides',
                                                       'total sulfur dioxide'])])),
                    ('regressor',
                     LGBMRegressor(colsample_bytree=0.6505873538375593,
                                   lambda_l1=497.23364507194253,
                                   lambda_l2=10.247278083927856,
                                   learning_rate=0.010591811060159174, max_bin=496,
                                   max_depth=5, min_child_samples=41,
                                   n_estimators=162, num_leaves=9,
                                   random_state=668290694,
                                   subsample=0.6795749046696467))])

ColumnSelector

    ColumnSelector(cols=['alcohol', 'density', 'fixed acidity', 'residual sugar',
                         'sulphates', 'volatile acidity', 'citric acid',
                         'free sulfur dioxide', 'pH', 'chlorides',
                         'total sulfur dioxide'])

preprocessor: ColumnTransformer

    ColumnTransformer(remainder='passthrough', sparse_threshold=0,
                      transformers=[('numerical',
                                     Pipeline(steps=[('converter',
                                                      FunctionTransformer(func=<function <lambda> at 0x7fa5d6f6cca0>)),
                                                     ('imputers',
                                                      ColumnTransformer(transformers=[('impute_mean',
                                                                                       SimpleImputer(),
                                                                                       ['alcohol',
                                                                                        'chlorides',
                                                                                        'citric '
                                                                                        'acid',
                                                                                        'density',
                                                                                        'fixed '
                                                                                        'acidity',
                                                                                        'free '
                                                                                        'sulfur '
                                                                                        'dioxide',
                                                                                        'pH',
                                                                                        'residual '
                                                                                        'sugar',
                                                                                        'sulphates',
                                                                                        'total '
                                                                                        'sulfur '
                                                                                        'dioxide',
                                                                                        'volatile '
                                                                                        'acidity'])])),
                                                     ('standardizer',
                                                      StandardScaler())]),
                                     ['alcohol', 'density', 'fixed acidity',
                                      'residual sugar', 'sulphates',
                                      'volatile acidity', 'citric acid',
                                      'free sulfur dioxide', 'pH', 'chlorides',
                                      'total sulfur dioxide'])])

numerical

    ['alcohol', 'density', 'fixed acidity', 'residual sugar', 'sulphates', 'volatile acidity', 'citric acid', 'free sulfur dioxide', 'pH', 'chlorides', 'total sulfur dioxide']

FunctionTransformer

    FunctionTransformer(func=<function <lambda> at 0x7fa5d6f6cca0>)

imputers: ColumnTransformer

    ColumnTransformer(transformers=[('impute_mean', SimpleImputer(),
                                     ['alcohol', 'chlorides', 'citric acid',
                                      'density', 'fixed acidity',
                                      'free sulfur dioxide', 'pH', 'residual sugar',
                                      'sulphates', 'total sulfur dioxide',
                                      'volatile acidity'])])

impute_mean

    ['alcohol', 'chlorides', 'citric acid', 'density', 'fixed acidity', 'free sulfur dioxide', 'pH', 'residual sugar', 'sulphates', 'total sulfur dioxide', 'volatile acidity']

SimpleImputer

    SimpleImputer()

StandardScaler

    StandardScaler()

remainder

    []

passthrough

    passthrough

LGBMRegressor

    LGBMRegressor(colsample_bytree=0.6505873538375593, lambda_l1=497.23364507194253,
                  lambda_l2=10.247278083927856, learning_rate=0.010591811060159174,
                  max_bin=496, max_depth=5, min_child_samples=41, n_estimators=162,
                  num_leaves=9, random_state=668290694,
                  subsample=0.6795749046696467)